.. _utils_ensemble_api:

Validation checks used in ensembles
===================================

.. automodule:: imbalanced_ensemble.utils
    :no-members:
    :no-inherited-members:

.. currentmodule:: imbalanced_ensemble.utils

.. autosummary::
   :toctree: _autosummary
   :template: function.rst

   check_eval_datasets
   check_eval_metrics
   check_target_label_and_n_target_samples
   check_balancing_schedule